Class: Google::Cloud::PolicyTroubleshooter::Iam::V3::ConditionExplanation::EvaluationState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb

Overview

Evaluated state of a condition expression.

Instance Attribute Summary collapse

Instance Attribute Details

#end::Integer

Returns End position of an expression in the condition, by character, end included, for example: the end position of the first part of a==b || c==d would be 4.

Returns:

  • (::Integer)

    End position of an expression in the condition, by character, end included, for example: the end position of the first part of a==b || c==d would be 4.



704
705
706
707
# File 'proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb', line 704

class EvaluationState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#errors::Array<::Google::Rpc::Status>

Returns Any errors that prevented complete evaluation of the condition expression.

Returns:

  • (::Array<::Google::Rpc::Status>)

    Any errors that prevented complete evaluation of the condition expression.



704
705
706
707
# File 'proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb', line 704

class EvaluationState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start::Integer

Returns Start position of an expression in the condition, by character.

Returns:

  • (::Integer)

    Start position of an expression in the condition, by character.



704
705
706
707
# File 'proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb', line 704

class EvaluationState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#value::Google::Protobuf::Value

Returns Value of this expression.

Returns:



704
705
706
707
# File 'proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb', line 704

class EvaluationState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end