Class: Google::Cloud::PolicyTroubleshooter::Iam::V3::ConditionExplanation::EvaluationState
- Inherits:
-
Object
- Object
- Google::Cloud::PolicyTroubleshooter::Iam::V3::ConditionExplanation::EvaluationState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb
Overview
Evaluated state of a condition expression.
Instance Attribute Summary collapse
-
#end ⇒ ::Integer
End position of an expression in the condition, by character, end included, for example: the end position of the first part of
a==b || c==dwould be 4. -
#errors ⇒ ::Array<::Google::Rpc::Status>
Any errors that prevented complete evaluation of the condition expression.
-
#start ⇒ ::Integer
Start position of an expression in the condition, by character.
-
#value ⇒ ::Google::Protobuf::Value
Value of this expression.
Instance Attribute Details
#end ⇒ ::Integer
Returns End position of an expression in the condition, by character,
end included, for example: the end position of the first part of
a==b || c==d would be 4.
704 705 706 707 |
# File 'proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb', line 704 class EvaluationState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#errors ⇒ ::Array<::Google::Rpc::Status>
Returns Any errors that prevented complete evaluation of the condition expression.
704 705 706 707 |
# File 'proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb', line 704 class EvaluationState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#start ⇒ ::Integer
Returns Start position of an expression in the condition, by character.
704 705 706 707 |
# File 'proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb', line 704 class EvaluationState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#value ⇒ ::Google::Protobuf::Value
Returns Value of this expression.
704 705 706 707 |
# File 'proto_docs/google/cloud/policytroubleshooter/iam/v3/troubleshooter.rb', line 704 class EvaluationState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |